@@ -19,13 +19,15 @@ use Lemonldap::NG::Common::Conf;              #link protected conf Configuration
 use Lemonldap::NG::Common::Conf::Constants;   #inherits
 require Lemonldap::NG::Manager::_i18n;        #inherits
 use utf8;
+use Data::Dumper;
+$Data::Dumper::Indent = 0;
 
 #inherits Apache::Session
 
 #our $whatToTrace;
 #*whatToTrace = \$Lemonldap::NG::Handler::_CGI::whatToTrace;
 
-our $VERSION = '1.4.1';
+our $VERSION = '1.4.6';
 
 our @ISA = qw(
   Lemonldap::NG::Handler::CGI
@@ -520,11 +522,13 @@ sub session {
         'connectionTitle' => [qw(ipAddr _timezone _url)],
         'authenticationTitle' =>
           [qw(_session_id _user _password authenticationLevel)],
-        'modulesTitle' => [qw(_auth _userDB _passwordDB _issuerDB _authChoice)],
-        'saml'         => [
+        'modulesTitle' => [
+            qw(_auth _userDB _passwordDB _issuerDB _authChoice _authMulti _userDBMulti)
+        ],
+        'saml' => [
             qw(_idp _idpConfKey _samlToken _lassoSessionDump _lassoIdentityDump)
         ],
-        'groups'    => [qw(groups)],
+        'groups'    => [qw(groups hGroups)],
         'ldap'      => [qw(dn)],
         'BrowserID' => [qw(_browserIdAnswer _browserIdAnswerRaw)],
     };
@@ -557,7 +561,7 @@ sub session {
               . '</strong> (<tt>$'
               . $attribute
               . '</tt>): '
-              . $session{$attribute} . '</li>';
+              . ( ref($session{$attribute}) ? Dumper($session{$attribute}) : $session{$attribute} ). '</li>';
 
             # Delete attribute, to hide it
             delete $session{$attribute};
